from fastapi.testclient import TestClient

from geomagio.api.ws import app

client = TestClient(app)


def test_get_all_observatories():
    response = client.get("/observatories/")

    assert response.status_code == 200
    body = response.json()
    assert body["type"] == "FeatureCollection"

    observatories = body["features"]
    for o in observatories:
        assert o["type"] == "Feature"
        assert o["id"] != None
        assert o["properties"]["name"] != None
        assert o["properties"]["agency"] != None
        assert o["properties"]["agency_name"] != None
        assert o["properties"]["sensor_orientation"] != None
        assert o["properties"]["sensor_sampling_rate"] != None


def test_get_observatory_by_id():
    response = client.get("/observatories/SIT")

    assert response.status_code == 200

    body = response.json()
    assert body["type"] == "Feature"
    assert body["id"] == "SIT"
    assert body["properties"]["name"] == "Sitka"
    assert body["properties"]["agency"] == "USGS"
    assert body["properties"]["agency_name"] == "United States Geological Survey (USGS)"
    assert body["properties"]["sensor_orientation"] == "HDZ"
    assert body["properties"]["sensor_sampling_rate"] == 100.0
    assert body["properties"]["declination_base"] == 12349
    assert body["geometry"]["type"] == "Point"
    assert body["geometry"]["coordinates"] == [224.675, 57.058, 24]
